@@ -8,13 +8,14 @@ from classification_model.config.core import config
 from classification_model.preprocessing.data_manager import load_trained
 from classification_model.preprocessing.validation import validate_inputs
 
-save_file_name_model = f"{config.app_config.model_save_file}{_version}.h5"
+save_file_name_model = f"{config.app_config.model_save_file}{_version}.tflite"
 save_file_name_enc = f"{config.app_config.model_save_file}{_version}.joblib"
 save_file_name_pp = f"{config.app_config.model_save_file}_preprocess{_version}.joblib"
 
 _text_process_pipe = load_trained(file_name=save_file_name_pp)
 _lab_enc = load_trained(file_name=save_file_name_enc)
 _model_load = load_trained(file_name=save_file_name_model)
+_model_load.allocate_tensors()
 
 
 def make_prediction(
@@ -26,14 +27,31 @@ def make_prediction(
     data = input_data
     validated_data, errors = validate_inputs(input_data=data)
     validated_data = validated_data[config.model_config.INDEPENDENT_FEATURES]
+    processed_data = _text_process_pipe.transform(validated_data)
     results = {"predictions": None, "version": _version, "errors": errors}
 
     if not errors:
-        predictions = np.argmax(
-            _model_load.predict(_text_process_pipe.transform(validated_data)), axis=-1
-        )
+        predictions = []
+        # Preprocess the image to required size and cast
+        for indx in range(len(processed_data)):
+            # set the tensor to point to the input data to be inferred
+            _model_load.set_tensor(
+                _model_load.get_input_details()[0]["index"],  # input index
+                np.array(np.expand_dims(  # input tensor
+                    processed_data[indx], 0), dtype=np.float32))
+
+            # Run the inference
+            _model_load.invoke()
+            predictions.append(
+                _lab_enc.inverse_transform(
+                    np.argmax(
+                        _model_load.get_tensor(
+                            _model_load.get_output_details()[0]['index']
+                        ), axis=-1)
+                )[0])
+
         results = {
-            "predictions": list(_lab_enc.inverse_transform(predictions)),
+            "predictions": predictions,
             "version": _version,
             "errors": errors,
         }
